@@ -13,22 +13,81 @@ from colorama import *
 from web import *
 from PyQt5.Qt import PYQT_VERSION_STR
 from PyQt5.QtCore import QT_VERSION_STR
-from downloader import *
 import os
-os.system('"J:\py3.9\python.exe"')
+import subprocess
+from pip_install import install,uninstall
 
 init(autoreset=True)
 
 
-#Ui_MainWindow,_ = loadUiType('downloader.ui')
+Ui_MainWindow,_ = loadUiType('sources/downloader.ui')
+Fast_link,_ = loadUiType('sources/fast_link.ui')
+Python_script,_ = loadUiType('sources/python_script.ui')
+py_inst,_ = loadUiType('sources/py.ui')
+class moudle_installer(QtWidgets.QMainWindow,py_inst):
+    def __init__(self):
+        super(moudle_installer,self).__init__()
+        self.setupUi(self)
+        self.pushButton.clicked.connect(self.install)
 
 
+    def install(self):
+        text = ''
+        for i in install(self.lineEdit.text()):
+            text += i
+        self.textBrowser.setText(text)
+
+
+
+class PS(QtWidgets.QMainWindow,Python_script):
+    un = pyqtSignal()
+    def __init__(self):
+
+        super(PS, self).__init__()
+        self.setupUi(self)
+        self.pushButton.clicked.connect(self.runs)
+    def runs(self):
+        self.un.emit()
+    def run_script(self):
+        try:
+            s = self.textEdit.toPlainText()
+            with open('test.py','w') as f:
+                f.write(s)
+            tex = ''
+
+            for i in self.os_popen(f'{sys.executable} test.py'):
+                tex += i
+            if tex:
+                self.textBrowser.setText(tex)
+            else:
+                self.textBrowser.setText('It is Empty!Is Exception happened?Please look of cmd or Idle output.')
+        except BaseException as e:
+            print(e,sys.executable)
+    def os_popen(self,strt):
+        try:
+            self.textBrowser.setText('')
+            re = os.popen(strt).readlines()
+            return re
+        except BaseException as e:
+            print(e)
+class Fast(QtWidgets.QMainWindow,Fast_link):
+    a = pyqtSignal()
+    b = pyqtSignal()
+    def __init__(self):
+
+        super(Fast, self).__init__()
+        self.setupUi(self)
+        self.pushButton.clicked.connect(self.start_PS)
+        self.pushButton_2.clicked.connect(self.b.emit)
+    def start_PS(self):
+        self.a.emit()
 
 
 
 
 class window(QtWidgets.QMainWindow,Ui_MainWindow):
     signal = pyqtSignal()
+    fast_link = pyqtSignal()
     def __init__(self):
 
 
@@ -40,11 +99,12 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.te = ''
         self.progressBar.setValue(0)
         self.pushButton_2.clicked.connect(self.fwa)
+        self.pushButton_3.clicked.connect(self.fast)
         self.wdw = ''
 
 
 
-        self.setWindowIcon(QIcon('icon.bmp'))
+        self.setWindowIcon(QIcon('sources/icon.bmp'))
         self.log(f'[{time.ctime()}][main/Info] icon loaded')
 
         try:
@@ -64,6 +124,10 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         self.log(f'[{time.ctime()}][main/Info] timer initlazing sucsess')
         self.log(
             f'[{time.ctime()}][main/Info] backend library:PyQt5 version {PYQT_VERSION_STR} build on Qt {QT_VERSION_STR}')
+    def fast(self):
+        self.log(
+            f'[{time.ctime()}][main/Info] fast link started')
+        self.fast_link.emit()
     def log(self,text,color=Fore.RESET):
         print(color+text)
         try:
@@ -164,7 +228,8 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
             self.u(50)
             self.update('downloading')
             self.u(60)
-            aaaaa = self.lineEdit_2.text()+text[-1].replace('/','')\
+            if self.lineEdit_2.text() != '':
+                aaaaa = self.lineEdit_2.text()+'/'+text[-1].replace('/','')\
             .replace(r'\\', '')\
             .replace(':', '')\
             .replace('*', '')\
@@ -172,7 +237,18 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
             .replace('"','') \
             .replace('<', '') \
             .replace('>', '') \
-            .replace('|', '') \
+            .replace('|', '')
+            else:
+                aaaaa = text[-1].replace('/', '') \
+                    .replace(r'\\', '') \
+                    .replace(':', '') \
+                    .replace('*', '') \
+                    .replace('?', '') \
+                    .replace('"', '') \
+                    .replace('<', '') \
+                    .replace('>', '') \
+                    .replace('|', '')
+
 
             aaa = str(time.time())
             with open(aaaaa,'ab+') as f:
@@ -230,17 +306,35 @@ class window(QtWidgets.QMainWindow,Ui_MainWindow):
         else:
 
             self.progressBar.setValue(v)
+class Main:
+    def __init__(self):
+        self.app = QtWidgets.QApplication(sys.argv)
+        self.d = moudle_installer()
+        self.a = PS()
+        self.fast = Fast()
+        self.window = window()
+    def connect(self):
+        self.a.un.connect(self.a.run_script)
+
+        self.fast.a.connect(self.a.show)
+        self.fast.b.connect(self.d.show)
+        self.window.fast_link.connect(self.fast.show)
+    def run(self):
+        self.window.show()
+        sys.exit(self.app.exec_())
 if __name__ == '__main__':
+    mainclass = Main()
+    mainclass.connect()
+    mainclass.run()
+
+
+
 
 
-    app = QtWidgets.QApplication(sys.argv)
-    window = window()
-    window.show()
 
-    sys.exit(app.exec_())
 else:
     print(f'[{time.ctime()}][main/Info] now varbile "__name__"={__name__},run in web mode')
-    run('1.0.7')
+    run('1.0.8')
 
 
 
